@@ -1,12 +1,10 @@
-/*
- * This file is part of Freecell Solver. It is subject to the license terms in
- * the COPYING.txt file found in the top-level directory of this distribution
- * and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
- * Freecell Solver, including this file, may be copied, modified, propagated,
- * or distributed except according to the terms contained in the COPYING file.
- *
- * Copyright (c) 2000 Shlomi Fish
- */
+// This file is part of Freecell Solver. It is subject to the license terms in
+// the COPYING.txt file found in the top-level directory of this distribution
+// and at http://fc-solve.shlomifish.org/docs/distro/COPYING.html . No part of
+// Freecell Solver, including this file, may be copied, modified, propagated,
+// or distributed except according to the terms contained in the COPYING file.
+//
+// Copyright (c) 2000 Shlomi Fish
 #include <db.h>
 
 #include "dbm_solver.h"
@@ -36,7 +34,7 @@ void fc_solve_dbm_store_init(fcs_dbm_store *const store, const char *const path,
 
     if ((ret = db_create(&(db->dbp), NULL, 0)) != 0)
     {
-        fc_solve_err("db_create: %s\n", db_strerror(ret));
+        exit_error("db_create: %s\n", db_strerror(ret));
     }
 
     if ((ret = db->dbp->open(
@@ -68,11 +66,11 @@ bool fc_solve_dbm_store_does_key_exist(
     int ret;
     if ((ret = db->dbp->get(db->dbp, NULL, &(db->key), &(db->data), 0)) == 0)
     {
-        return TRUE;
+        return true;
     }
     else if (ret == DB_NOTFOUND)
     {
-        return FALSE;
+        return false;
     }
     else
     {
@@ -94,11 +92,11 @@ bool fc_solve_dbm_store_lookup_parent(fcs_dbm_store store,
     if ((ret = db->dbp->get(db->dbp, NULL, &(db->key), &(db->data), 0)) == 0)
     {
         parent[0] = db->data.size - 1;
-        return TRUE;
+        return true;
     }
     else if (ret == DB_NOTFOUND)
     {
-        return FALSE;
+        return false;
     }
     else
     {
@@ -138,7 +136,7 @@ extern void fc_solve_dbm_store_destroy(fcs_dbm_store store)
     int ret;
     if ((ret = db->dbp->close(db->dbp, 0)) != 0)
     {
-        fc_solve_err("DB close failed with ret=%d\n", ret);
+        exit_error("DB close failed with ret=%d\n", ret);
     }
     free(db);
 }
