@@ -48,8 +48,9 @@ my $args = {
                     't'     => "T",
                     'non_t' => "10",
                 },
-                ,
-                "J", "Q", "K"
+
+                "J", "Q",
+                "K"
             )
         ]
     ),
